==> odata-client-microsoft-dynamics-0.1.53-sources.jar: microsoft/dynamics/crm/complex/AppValidationResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ValidationSuccess", 
    "ValidationIssueList"})
@JsonInclude(Include.NON_NULL)
public class AppValidationResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ValidationSuccess")
    protected Boolean validationSuccess;

    @JsonProperty("ValidationIssueList")
    protected List<ValidationIssue> validationIssueList;

    @JsonProperty("ValidationIssueList@nextLink")
    protected String validationIssueListNextLink;

    protected AppValidationResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.AppValidationResponse";
    }

    @Property(name="ValidationSuccess")
    @JsonIgnore
    public Optional<Boolean> getValidationSuccess() {
        return Optional.ofNullable(validationSuccess);
    }

    public AppValidationResponse withValidationSuccess(Boolean validationSuccess) {
        AppValidationResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.AppValidationResponse");
        _x.validationSuccess = validationSuccess;
        return _x;
    }

    @Property(name="ValidationIssueList")
    @JsonIgnore
    public CollectionPage<ValidationIssue> getValidationIssueList() {
        return new CollectionPage<ValidationIssue>(contextPath, ValidationIssue.class, this.validationIssueList, Optional.ofNullable(validationIssueListNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="ValidationIssueList")
    @JsonIgnore
    public CollectionPage<ValidationIssue> getValidationIssueList(HttpRequestOptions options) {
        return new CollectionPage<ValidationIssue>(contextPath, ValidationIssue.class, this.validationIssueList, Optional.ofNullable(validationIssueListNextLink), Collections.emptyList(), options);
    }

    public AppValidationResponse withUnmappedField(String name, String value) {
        AppValidationResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean validationSuccess;
        private List<ValidationIssue> validationIssueList;
        private String validationIssueListNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder validationSuccess(Boolean validationSuccess) {
            this.validationSuccess = validationSuccess;
            this.changedFields = changedFields.add("ValidationSuccess");
            return this;
        }

        public Builder validationIssueList(List<ValidationIssue> validationIssueList) {
            this.validationIssueList = validationIssueList;
            this.changedFields = changedFields.add("ValidationIssueList");
            return this;
        }

        public Builder validationIssueList(ValidationIssue... validationIssueList) {
            return validationIssueList(Arrays.asList(validationIssueList));
        }

        public Builder validationIssueListNextLink(String validationIssueListNextLink) {
            this.validationIssueListNextLink = validationIssueListNextLink;
            this.changedFields = changedFields.add("ValidationIssueList");
            return this;
        }

        public AppValidationResponse build() {
            AppValidationResponse _x = new AppValidationResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.AppValidationResponse";
            _x.validationSuccess = validationSuccess;
            _x.validationIssueList = validationIssueList;
            _x.validationIssueListNextLink = validationIssueListNextLink;
            return _x;
        }
    }

    private AppValidationResponse _copy() {
        AppValidationResponse _x = new AppValidationResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.validationSuccess = validationSuccess;
        _x.validationIssueList = validationIssueList;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AppValidationResponse[");
        b.append("ValidationSuccess=");
        b.append(this.validationSuccess);
        b.append(", ");
        b.append("ValidationIssueList=");
        b.append(this.validationIssueList);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.2.2-sources.jar: microsoft/dynamics/crm/complex/AppValidationResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ValidationSuccess", 
    "ValidationIssueList"})
@JsonInclude(Include.NON_NULL)
public class AppValidationResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ValidationSuccess")
    protected Boolean validationSuccess;

    @JsonProperty("ValidationIssueList")
    protected List<ValidationIssue> validationIssueList;

    @JsonProperty("ValidationIssueList@nextLink")
    protected String validationIssueListNextLink;

    protected AppValidationResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.AppValidationResponse";
    }

    @Property(name="ValidationSuccess")
    @JsonIgnore
    public Optional<Boolean> getValidationSuccess() {
        return Optional.ofNullable(validationSuccess);
    }

    public AppValidationResponse withValidationSuccess(Boolean validationSuccess) {
        AppValidationResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.AppValidationResponse");
        _x.validationSuccess = validationSuccess;
        return _x;
    }

    @Property(name="ValidationIssueList")
    @JsonIgnore
    public CollectionPage<ValidationIssue> getValidationIssueList() {
        return new CollectionPage<ValidationIssue>(contextPath, ValidationIssue.class, this.validationIssueList, Optional.ofNullable(validationIssueListNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="ValidationIssueList")
    @JsonIgnore
    public CollectionPage<ValidationIssue> getValidationIssueList(HttpRequestOptions options) {
        return new CollectionPage<ValidationIssue>(contextPath, ValidationIssue.class, this.validationIssueList, Optional.ofNullable(validationIssueListNextLink), Collections.emptyList(), options);
    }

    public AppValidationResponse withUnmappedField(String name, Object value) {
        AppValidationResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean validationSuccess;
        private List<ValidationIssue> validationIssueList;
        private String validationIssueListNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder validationSuccess(Boolean validationSuccess) {
            this.validationSuccess = validationSuccess;
            this.changedFields = changedFields.add("ValidationSuccess");
            return this;
        }

        public Builder validationIssueList(List<ValidationIssue> validationIssueList) {
            this.validationIssueList = validationIssueList;
            this.changedFields = changedFields.add("ValidationIssueList");
            return this;
        }

        public Builder validationIssueList(ValidationIssue... validationIssueList) {
            return validationIssueList(Arrays.asList(validationIssueList));
        }

        public Builder validationIssueListNextLink(String validationIssueListNextLink) {
            this.validationIssueListNextLink = validationIssueListNextLink;
            this.changedFields = changedFields.add("ValidationIssueList");
            return this;
        }

        public AppValidationResponse build() {
            AppValidationResponse _x = new AppValidationResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.AppValidationResponse";
            _x.validationSuccess = validationSuccess;
            _x.validationIssueList = validationIssueList;
            _x.validationIssueListNextLink = validationIssueListNextLink;
            return _x;
        }
    }

    private AppValidationResponse _copy() {
        AppValidationResponse _x = new AppValidationResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.validationSuccess = validationSuccess;
        _x.validationIssueList = validationIssueList;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AppValidationResponse[");
        b.append("ValidationSuccess=");
        b.append(this.validationSuccess);
        b.append(", ");
        b.append("ValidationIssueList=");
        b.append(this.validationIssueList);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
